==> jimubi-spring-boot-starter-1.9.3.jar: org/jeecg/modules/drag/sql/OnlDragDataSourceDao_selectCondition.sql <==
<#assign query_field_no=0>
<#if queryFields.conditionList ?? && (queryFields.conditionList ?size gt 0)>
    <#list queryFields.conditionList as po>
        <#if query_field_no==0>
             <#if timeCondition ?? && (timeCondition ?size gt 0)>
                AND(
             <#else>
                WHERE
            </#if>
        <#else>
            ${queryFields.filterMode}
        </#if>
        <#if ( po.cType )?? && po.cType?length gt 0 >
          /*为空不为空*/
          <#if po.cType =='7' || po.cType =='8'>
            ${po.field} ${po.expression}
          </#if>
          /*在不在范围内*/
          <#if po.cType =='9' || po.cType =='10'>
           ${po.field} ${po.expression} '${po.begin}' and '${po.end}'
          </#if>
          /*等不等于*/
          <#if po.cType =='1' || po.cType =='2'>
           ${po.field} ${po.expression} '${po.value}'
          </#if>
          /*其他包含*/
          <#if  po.cType =='3' || po.cType =='4' || po.cType =='5' || po.cType =='6'>
            <#if po.type =='select'>
                <#assign val_list="${po.value}"?eval />
                <#if val_list?? && (val_list?size > 0)>
                ${po.field} ${po.expression}(
                    <#list val_list as _v>
                    '${_v?string}'
                    <#if _v_has_next>
                    ,
                    </#if>
                    </#list>
                </#if>
                )
            <#else>
               ${po.field} ${po.expression} '${po.value}'
            </#if>
          </#if>
        <#else>
         ${po.field} ${po.expression} '${po.value}'
        </#if>
<#assign query_field_no=query_field_no+1>
</#list>
<#if timeCondition ?? && (timeCondition ?size gt 0)>
)
</#if>
</#if>

==> jimubi-spring-boot-starter-2.1.4.jar: org/jeecg/modules/drag/sql/OnlDragDataSourceDao_selectCondition.sql <==
<#assign query_field_no=0>
<#if queryFields.conditionList ?? && (queryFields.conditionList ?size gt 0)>
    <#list queryFields.conditionList as po>
        <#if query_field_no==0>
             <#if timeCondition ?? && (timeCondition ?size gt 0)>
                AND(
             <#else>
                WHERE
            </#if>
        <#else>
            ${queryFields.filterMode}
        </#if>
        <#if ( po.cType )?? && po.cType?length gt 0 >
          /*为空不为空*/
          <#if po.cType =='7' || po.cType =='8'>
            ${po.field} ${po.expression}
          </#if>
          /*在不在范围内*/
          <#if po.cType =='9' || po.cType =='10'>
           ${po.field} ${po.expression} '${po.begin}' and '${po.end}'
          </#if>
          /*等不等于*/
          <#if po.cType =='1' || po.cType =='2'>
            <#if po.type =='date' && po.begin ?? && po.begin ?length gt 0 && po.end ?? && po.end ?length gt 0>
            <#assign expression = (po.cType == '1')?string("between", "not between")>
            ${po.field} ${expression} '${po.begin}' and '${po.end}'
            <#else>
            ${po.field} ${po.expression} '${po.value}'
            </#if>
          </#if>
          /*其他包含*/
          <#if po.cType =='3' || po.cType =='4' || po.cType =='5' || po.cType =='6'>
            <#if po.type =='select' || po.type =='pca'>
                <#if po.value?has_content>
                ${po.field} ${po.expression}(
                    <#assign val_list = po.value?split(",")>
                    <#list val_list as _v>
                    '${_v?string}'
                    <#if _v_has_next>
                    ,
                    </#if>
                    </#list>
                </#if>
                )
            <#else>
               ${po.field} ${po.expression} '${po.value}'
            </#if>
          </#if>
        <#else>
         ${po.field} ${po.expression} '${po.value}'
        </#if>
<#assign query_field_no=query_field_no+1>
</#list>
<#if timeCondition ?? && (timeCondition ?size gt 0)>
)
</#if>
</#if>
